@@ -8,8 +8,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017, 2018 The Sympa Community. See the AUTHORS.md file at the
-# top-level directory of this distribution and at
+# Copyright 2017, 2018, 2019, 2020 The Sympa Community. See the AUTHORS.md
+# file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -104,9 +104,7 @@ sub lists {
         my $listname = $list->{'name'};
 
         my $result_item = {};
-        my $result      = Sympa::Scenario::request_action(
-            $list,
-            'visibility',
+        my $result = Sympa::Scenario->new($list, 'visibility')->authz(
             'md5',
             {   'sender'                  => $sender,
                 'remote_application_name' => $ENV{'remote_application_name'}
@@ -193,12 +191,8 @@ sub login {
     }
 
     ## Create Sympa::WWW::Session object
-    my $session = Sympa::WWW::Session->new(
-        $robot,
-        {   'cookie' =>
-                Sympa::WWW::Session::encrypt_session_id($ENV{'SESSION_ID'})
-        }
-    );
+    my $session =
+        Sympa::WWW::Session->new($robot, {cookie => $ENV{SESSION_ID}});
     $ENV{'USER_EMAIL'} = $email;
     $session->{'email'} = $email;
     $session->store();
@@ -208,7 +202,7 @@ sub login {
 
     ## Also return the cookie value
     return SOAP::Data->name('result')->type('string')
-        ->value(Sympa::WWW::Session::encrypt_session_id($ENV{'SESSION_ID'}));
+        ->value($ENV{SESSION_ID});
 }
 
 sub casLogin {
@@ -289,12 +283,8 @@ sub casLogin {
     }
 
     ## Create Sympa::WWW::Session object
-    my $session = Sympa::WWW::Session->new(
-        $robot,
-        {   'cookie' =>
-                Sympa::WWW::Session::encrypt_session_id($ENV{'SESSION_ID'})
-        }
-    );
+    my $session =
+        Sympa::WWW::Session->new($robot, {cookie => $ENV{SESSION_ID}});
     $ENV{'USER_EMAIL'} = $email;
     $session->{'email'} = $email;
     $session->store();
@@ -304,7 +294,7 @@ sub casLogin {
 
     ## Also return the cookie value
     return SOAP::Data->name('result')->type('string')
-        ->value(Sympa::WWW::Session::encrypt_session_id($ENV{'SESSION_ID'}));
+        ->value($ENV{SESSION_ID});
 }
 
 ## Used to call a service as an authenticated user without using HTTP cookies
@@ -330,7 +320,7 @@ sub authenticateAndRun {
     ## Provided email is not trusted, we fetch the user email from the
     ## session_table instead
     my $session =
-        Sympa::WWW::Session->new($ENV{'SYMPA_ROBOT'}, {'cookie' => $cookie});
+        Sympa::WWW::Session->new($ENV{'SYMPA_ROBOT'}, {cookie => $cookie});
     if (defined $session) {
         $email      = $session->{'email'};
         $session_id = $session->{'id_session'};
@@ -509,8 +499,8 @@ sub info {
             ->faultdetail("List $listname unknown");
     }
 
-    my $result = Sympa::Scenario::request_action(
-        $list, 'info', 'md5',
+    my $result = Sympa::Scenario->new($list, 'info')->authz(
+        'md5',
         {   'sender'                  => $sender,
             'remote_application_name' => $ENV{'remote_application_name'}
         }
@@ -627,16 +617,16 @@ sub createList {
     my $spindle = Sympa::Spindle::ProcessRequest->new(
         context    => $robot,
         action     => 'create_list',
-        listname   => $listname,
         parameters => {
-            owner => [
+            listname => $listname,
+            owner    => [
                 {   email => $sender,
                     gecos => ($user ? $user->{gecos} : undef),
                 }
             ],
             subject        => $subject,
             creation_email => $sender,
-            template       => $list_tpl,
+            type           => $list_tpl,
             topics         => $topics,
             description    => $description,
         },
@@ -964,8 +954,8 @@ sub review {
     # Part of the authorization code
     $user = Sympa::User::get_global_user($sender);
 
-    my $result = Sympa::Scenario::request_action(
-        $list, 'review', 'md5',
+    my $result = Sympa::Scenario->new($list, 'review')->authz(
+        'md5',
         {   'sender'                  => $sender,
             'remote_application_name' => $ENV{'remote_application_name'}
         }
@@ -988,13 +978,6 @@ sub review {
         my $is_owner = $list->is_admin('owner', $sender)
             || Sympa::is_listmaster($list, $sender);
 
-        ## Members list synchronization if include is in use
-        if ($list->has_include_data_sources()) {
-            unless (defined $list->on_the_fly_sync_include(use_ttl => 1)) {
-                $log->syslog('notice', 'Unable to synchronize list %s',
-                    $list);
-            }
-        }
         unless ($user = $list->get_first_list_member({'sortby' => 'email'})) {
             $log->syslog('err', 'No subscribers in list "%s"',
                 $list->{'name'});
@@ -1066,13 +1049,6 @@ sub fullReview {
             ->faultdetail('Listmaster or listowner required');
     }
 
-    # Members list synchronization if include is in use
-    if ($list->has_include_data_sources()) {
-        unless (defined $list->on_the_fly_sync_include(use_ttl => 1)) {
-            $log->syslog('notice', 'Unable to synchronize list %s', $list);
-        }
-    }
-
     my $members;
     my $user;
     if ($user = $list->get_first_list_member({'sortby' => 'email'})) {
@@ -1292,9 +1268,7 @@ sub which {
 
         my $result_item;
 
-        my $result = Sympa::Scenario::request_action(
-            $list,
-            'visibility',
+        my $result = Sympa::Scenario->new($list, 'visibility')->authz(
             'md5',
             {   'sender'                  => $sender,
                 'remote_application_name' => $ENV{'remote_application_name'}
